@@ -168,7 +168,7 @@ class WrappedAnonymizer(SupervisedLearningAnonymizer):
         if hasattr(self._anonymizer, "save"):
             self._anonymizer.save(filepath)
         elif self._serialize is not None:
-            self._serialize(self._anonymizer, filepath)
+            self._serialize(self, filepath)
         else:
             raise NotImplementedError(
                 "Anonymizer object does not provide a save function and a "
