@@ -11,6 +11,8 @@ import requests
 
 from . import anonymizer
 
+logger = logging.getLogger(__name__)
+
 
 class InferenceResource:
     """This resource is intended for fitting estimator following the supervised
@@ -60,6 +62,10 @@ class InferenceResource:
         )
 
         batch_size = req.get_param_as_int("batch_size", default=None)
+        logger.debug(
+            f"Inferring targets for feature array with shape {X.shape} and "
+            f"dtype {X.dtype}. Using batch size {batch_size}"
+        )
         prediction = self._loaded_model.predict(X=X, batch_size=batch_size)
         resp.data = utils.named_ndarrays_to_bytes(dict(prediction=prediction))
         resp.status = falcon.HTTP_CREATED
@@ -79,8 +85,16 @@ class InferenceResource:
         )
 
         X = array[self._expected_array_label]
+        logger.debug(
+            f"Received feature array for evaluation with shape {X.shape} and dtype "
+            f"{X.dtype}. Inferring its targets using batch size "
+            f"{self._default_batch_size}"
+        )
         prediction = self._loaded_model.predict(X, self._default_batch_size)
-
+        logger.debug(
+            f"Inferred targets for evaluation. The target's shape is {prediction.shape}"
+            f" and its dtype is {prediction.dtype}"
+        )
         try:
             evaluation_response = requests.post(
                 url=self._url_mapper["utility"],
@@ -110,10 +124,8 @@ class InferenceResource:
 
     def _load_most_recent_model(self) -> None:
         if not self._model_filepath.exists():
-            error_msg = "This anonymizer is not fitted/trained yet."
-            logging.exception(error_msg)
-            raise falcon.HTTPBadRequest(
-                description=error_msg,
+            raise falcon.HTTPServiceUnavailable(
+                description="This anonymizer is not fitted/trained yet.",
             )
         mod_time_from_disk = datetime.fromtimestamp(
             self._model_filepath.stat().st_mtime
